# Source with dec 3476/4822 and NSB tuning

## 20220523

## Short description of the config

Config for a source with dec 3476/4822 and NSB tuning:

    "image_modifier": {
        "increase_nsb": true,
        "extra_noise_in_dim_pixels": 0.977,
        "extra_bias_in_dim_pixels": 0.388,
        "transition_charge": 8,
        "extra_noise_in_bright_pixels": 1.197
    }	

## Why this config is needed 

See wiki page (src 3)
https://www.lst1.iac.es/wiki/index.php/MC_analysis_and_IRF_production#lstmcpipe_productions